Module handler

Module handler 

Multiplexed handler — routes Coordinator and Step tasks.

ActionQueue takes a single ExecutorHandler. This module provides FlowHandler, which inspects the task payload to determine the task type and routes to the appropriate execution path.

Structs

FlowHandler
The top-level handler registered with ActionQueue.